@@ -101,6 +101,113 @@ extractX.AICglm.lm <- function(cand.set, ...) {
 
 
 
+##glmmTMB
+extractX.AICglmmTMB <- function(cand.set, ...) {
+    
+    ##extract predictors from list
+    form.list <- as.character(lapply(cand.set, FUN = function(x) formula(x)[[3]]))
+    ##extract based on "+"
+    form.noplus <- unlist(sapply(form.list, FUN = function(i) strsplit(i, split = "\\+")))
+    ##remove extra white space
+    form.clean <- gsub("(^ +)|( +$)", "", form.noplus)
+    unique.clean <- unique(form.clean)
+    ##exclude empty strings and intercept
+    unique.predictors <- unique.clean[nchar(unique.clean) != 0 & unique.clean != "1"]
+
+    ##extract response
+    resp <- unique(as.character(sapply(cand.set, FUN = function(x) formula(x)[[2]])))
+    ##check if different response used
+    if(length(resp) > 1) stop("\nThe response variable should be identical in all models\n")
+    
+    
+    ##check for | in variance terms
+    pipe.id <- which(regexpr("\\|", unique.predictors) != -1)
+
+    ##remove variance terms from string of predictors
+    if(length(pipe.id) > 0) {unique.predictors <- unique.predictors[-pipe.id]}
+    
+    
+    ##extract data from model objects
+    dsets <- lapply(cand.set, FUN = function(i) (i$frame))
+
+    ##remove model names from list
+    names(dsets) <- NULL
+
+    ##combine data sets
+    combo <- do.call(what = "cbind", dsets)
+    dframe <- combo[, unique(names(combo))]
+
+    ##remove response from data frame
+    dframe <- dframe[, names(dframe) != resp]
+
+
+    ##check for interactions specified with *
+    inter.star <- any(regexpr("\\*", unique.predictors) != -1)
+    
+    ##check for interaction terms
+    inter.id <- any(regexpr("\\:", unique.predictors) != -1)
+    
+    ##inter.star and inter.id
+    if(inter.star && inter.id) {
+        ##separate terms in interaction
+        terms.nostar <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\*")))
+        ##remove extra white space
+        terms.nostar.clean <- gsub("(^ +)|( +$)", "", terms.nostar)
+        ##separate terms in interaction
+        terms.nointer <- unlist(sapply(terms.nostar.clean, FUN = function(i) strsplit(i, split = "\\:")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nointer)
+    }
+
+
+    ##inter.star
+    if(inter.star && !inter.id) {
+        ##separate terms in interaction
+        terms.nostar <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\*")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nostar)
+    }
+    
+        
+    ##inter.id
+    if(!inter.star && inter.id) {
+        ##separate terms in interaction
+        terms.nointer <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\:")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nointer)
+    }
+        
+
+    ##none
+    if(!inter.star && !inter.id) {
+        ##remove extra white space
+        terms.clean <- unique.predictors
+    }
+
+        
+    ##combine in single character vector
+    final.predictors <- unique(terms.clean)
+        
+    ##check for I( ) custom variables in formula
+    I.id <- which(regexpr("I\\(", final.predictors) != -1)
+        
+    ##if I( ) used
+    if(length(I.id) > 0) {
+        dframe <- dframe[, final.predictors[-I.id], drop = FALSE]
+    } else {
+        dframe <- dframe[, final.predictors, drop = FALSE]            
+    }
+
+    
+    ##assemble results
+    result <- list("predictors" = unique.predictors,
+                   "data" = dframe)
+    class(result) <- "extractX"
+    return(result)
+}
+
+
+
 ##gls
 extractX.AICgls <- function(cand.set, ...) {
     
@@ -2263,6 +2370,133 @@ extractX.AICunmarkedFitGPC <- function(cand.set, parm.type = NULL, ...) {
 
 
 
+##unmarkedFitOccu
+extractX.AICunmarkedFitOccuMulti <- function(cand.set, parm.type = NULL, ...) {
+
+    ##check for parm.type and stop if NULL
+    if(is.null(parm.type)) {stop("\n'parm.type' must be specified for this model type, see ?modavgPred for details\n")}
+
+    ##extract predictors from list
+    ##psi
+    if(identical(parm.type, "psi")) {
+        form.list <- lapply(cand.set, FUN = function(x) names(x@estimates@estimates$state@estimates))
+    }
+
+    ##detect
+    if(identical(parm.type, "detect")) {
+        form.list <- lapply(cand.set, FUN = function(x) names(x@estimates@estimates$det@estimates))
+    }
+
+
+    ##exclude empty strings and intercept
+    formStrings <- unlist(form.list)
+    notInclude <- grep(pattern = "(Intercept)", x = formStrings)
+    formNoInt <- formStrings[-notInclude]
+
+    ##extract only variable names
+    formJustVars <- unlist(strsplit(formNoInt, split = "\\]"))
+    formMat <- matrix(data = formJustVars, ncol = 2, byrow = TRUE)
+    ##remove extra white space
+    form.clean <- gsub("(^ +)|( +$)", "", formMat[, 2])
+    unique.predictors <- unique(form.clean)    
+
+    ##extract data from model objects - identical for all models
+    dsets <- lapply(cand.set, FUN = function(i) unmarked::getData(i))
+    ##check that same data are used
+    unique.dsets <- unique(dsets)
+    if(length(unique.dsets) != 1) stop("\nData sets differ across models:\n check data carefully\n")
+    unFrame <- unique.dsets[[1]]
+    
+    ##extract siteCovs
+    siteVars <- siteCovs(unFrame)
+    ##extract obsCovs
+    obsVars <- obsCovs(unFrame)
+
+    ##check for interactions specified with *
+    inter.star <- any(regexpr("\\*", unique.predictors) != -1)
+        
+    ##check for interaction terms
+    inter.id <- any(regexpr("\\:", unique.predictors) != -1)
+
+    ##inter.star and inter.id
+    if(inter.star && inter.id) {
+        ##separate terms in interaction
+        terms.nostar <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\*")))
+        ##remove extra white space
+        terms.nostar.clean <- gsub("(^ +)|( +$)", "", terms.nostar)
+        ##separate terms in interaction
+        terms.nointer <- unlist(sapply(terms.nostar.clean, FUN = function(i) strsplit(i, split = "\\:")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nointer)
+    }
+
+
+    ##inter.star
+    if(inter.star && !inter.id) {
+        ##separate terms in interaction
+        terms.nostar <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\*")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nostar)
+    }
+    
+        
+    ##inter.id
+    if(!inter.star && inter.id) {
+        ##separate terms in interaction
+        terms.nointer <- unlist(sapply(unique.predictors, FUN = function(i) strsplit(i, split = "\\:")))
+        ##remove extra white space
+        terms.clean <- gsub("(^ +)|( +$)", "", terms.nointer)
+    }
+        
+
+    ##none
+    if(!inter.star && !inter.id) {
+        ##remove extra white space
+        terms.clean <- unique.predictors
+    }
+
+        
+    ##combine in single character vector
+    final.predictors <- unique(terms.clean)
+        
+    ##find where predictors occur
+    if(!is.null(obsVars)) {
+        obsID <- obsVars[, intersect(final.predictors, names(obsVars)), drop = FALSE]
+        if(nrow(obsID) > 0) {
+            obsID.info <- capture.output(str(obsID))[-1]
+        } else {
+            obsID.info <- NULL
+        }
+    } else {obsID.info <- NULL}
+    
+    if(!is.null(siteVars)) {
+        siteID <- siteVars[, intersect(final.predictors, names(siteVars)), drop = FALSE]
+        if(nrow(siteID) > 0) {
+            siteID.info <- capture.output(str(siteID))[-1]
+        } else {
+            siteID.info <- NULL
+        }
+    } else {siteID.info <- NULL}
+
+    ##store data sets
+    data.out <- list( )
+    if(is.null(obsVars)) {
+        data.out$obsCovs <- NULL
+    } else {data.out$obsCovs <- obsID}
+    if(is.null(siteVars)) {
+        data.out$siteCovs <- NULL
+    } else {data.out$siteCovs <- siteID}
+
+    
+    ##assemble results
+    result <- list("predictors" = unique.predictors,
+                   "data" = data.out)
+    class(result) <- "extractX"
+    return(result)
+}
+
+
+
 ##print method
 print.extractX <- function(x, ...) {
     
